==> kazehakase-0.5.4.tar.gz: kazehakase-0.5.4/module/embed/webkit-gtk/kz-webkit-gtk.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/*
 *  Copyright (C) 2008  g新部 Hiroyuki Ikezoe
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */

#ifndef __KZ_WEBKIT_GTK_H__
#define __KZ_WEBKIT_GTK_H__

#include <gtk/gtkscrolledwindow.h>

G_BEGIN_DECLS

#define KZ_TYPE_WEBKIT_GTK		(kz_webkit_gtk_get_type ())
#define KZ_WEBKIT_GTK(obj)		(G_TYPE_CHECK_INSTANCE_CAST ((obj), KZ_TYPE_WEBKIT_GTK, KzGtkWebcore))
#define KZ_WEBKIT_GTK_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST ((klass), KZ_TYPE_WEBKIT_GTK, KzWebKitGtkClass))
#define KZ_IS_WEBKIT_GTK(obj)		(G_TYPE_CHECK_INSTANCE_TYPE ((obj), KZ_TYPE_WEBKIT_GTK))
#define KZ_IS_WEBKIT_GTK_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE ((klass), KZ_TYPE_WEBKIT_GTK))
#define KZ_WEBKIT_GTK_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS ((obj), KZ_TYPE_WEBKIT_GTK, KzWebKitGtkClass))

typedef struct _KzWebKitGtk		KzWebKitGtk;
typedef struct _KzWebKitGtkClass	KzWebKitGtkClass;

struct _KzWebKitGtk
{
	GtkScrolledWindow parent;
};

struct _KzWebKitGtkClass
{
	GtkScrolledWindowClass parent_class;
};


GType        kz_webkit_gtk_get_type              (void) G_GNUC_CONST;
void         kz_webkit_gtk_register_type         (GTypeModule *module);

G_END_DECLS

#endif /* __KZ_WEBKIT_GTK_H__ */

==> kazehakase_0.5.8.orig.tar.gz: kazehakase-0.5.8/module/embed/webkit-gtk/kz-webkit-gtk.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/*
 *  Copyright (C) 2008  g新部 Hiroyuki Ikezoe
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */

#ifndef __KZ_WEBKIT_GTK_H__
#define __KZ_WEBKIT_GTK_H__

#include <gtk/gtkscrolledwindow.h>

G_BEGIN_DECLS

#define KZ_TYPE_WEBKIT_GTK		(kz_webkit_gtk_get_type ())
#define KZ_WEBKIT_GTK(obj)		(G_TYPE_CHECK_INSTANCE_CAST ((obj), KZ_TYPE_WEBKIT_GTK, KzWebKitGtk))
#define KZ_WEBKIT_GTK_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST ((klass), KZ_TYPE_WEBKIT_GTK, KzWebKitGtkClass))
#define KZ_IS_WEBKIT_GTK(obj)		(G_TYPE_CHECK_INSTANCE_TYPE ((obj), KZ_TYPE_WEBKIT_GTK))
#define KZ_IS_WEBKIT_GTK_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE ((klass), KZ_TYPE_WEBKIT_GTK))
#define KZ_WEBKIT_GTK_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS ((obj), KZ_TYPE_WEBKIT_GTK, KzWebKitGtkClass))

typedef struct _KzWebKitGtk		KzWebKitGtk;
typedef struct _KzWebKitGtkClass	KzWebKitGtkClass;

struct _KzWebKitGtk
{
	GtkScrolledWindow parent;
};

struct _KzWebKitGtkClass
{
	GtkScrolledWindowClass parent_class;
};


GType        kz_webkit_gtk_get_type              (void) G_GNUC_CONST;
void         kz_webkit_gtk_register_type         (GTypeModule *module);

G_END_DECLS

#endif /* __KZ_WEBKIT_GTK_H__ */
